/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.gan.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * An AdvertiserResource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Affiliate Network API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Advertiser extends GenericJson {

  /**
   * True if the advertiser allows publisher created links, otherwise false.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean allowPublisherCreatedLinks;

  /**
   * Category that this advertiser belongs to. A valid list of categories can be found here:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107581
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String category;

  /**
   * The longest possible length of a commission (how long the cookies on the customer's browser
   * last before they expire).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer commissionDuration;

  /**
   * Email that this advertiser would like publishers to contact them with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String contactEmail;

  /**
   * Phone that this advertiser would like publishers to contact them with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String contactPhone;

  /**
   * The default link id for this advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long defaultLinkId;

  /**
   * Description of the website the advertiser advertises from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months. This value should be multiplied by 100 at the time of display.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcNinetyDayAverage;

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days. This value should be multiplied by 100 at the time of display.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcSevenDayAverage;

  /**
   * The ID of this advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * The requested advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Advertiser item;

  /**
   * Date that this advertiser was approved as a Google Affiliate Network advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime joinDate;

  /**
   * The kind for an advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * URL to the logo this advertiser uses on the Google Affiliate Network.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String logoUrl;

  /**
   * List of merchant center ids for this advertiser
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private java.util.List<Long> merchantCenterIds;

  /**
   * The name of this advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * A rank based on commissions paid to publishers over the past 90 days. A number between 1 and 4
   * where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least money
   * paid).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String payoutRank;

  /**
   * Allows advertisers to submit product listings to Google Product Search.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean productFeedsEnabled;

  /**
   * List of redirect URLs for this advertiser
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> redirectDomains;

  /**
   * URL of the website this advertiser advertises from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String siteUrl;

  /**
   * The status of the requesting publisher's relationship this advertiser.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * True if the advertiser allows publisher created links, otherwise false.
   * The value returned may be {@code null}.
   */
  public Boolean getAllowPublisherCreatedLinks() {
    return allowPublisherCreatedLinks;
  }

  /**
   * True if the advertiser allows publisher created links, otherwise false.
   * The value set may be {@code null}.
   */
  public Advertiser setAllowPublisherCreatedLinks(Boolean allowPublisherCreatedLinks) {
    this.allowPublisherCreatedLinks = allowPublisherCreatedLinks;
    return this;
  }

  /**
   * Category that this advertiser belongs to. A valid list of categories can be found here:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107581
   * The value returned may be {@code null}.
   */
  public String getCategory() {
    return category;
  }

  /**
   * Category that this advertiser belongs to. A valid list of categories can be found here:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107581
   * The value set may be {@code null}.
   */
  public Advertiser setCategory(String category) {
    this.category = category;
    return this;
  }

  /**
   * The longest possible length of a commission (how long the cookies on the customer's browser
   * last before they expire).
   * The value returned may be {@code null}.
   */
  public Integer getCommissionDuration() {
    return commissionDuration;
  }

  /**
   * The longest possible length of a commission (how long the cookies on the customer's browser
   * last before they expire).
   * The value set may be {@code null}.
   */
  public Advertiser setCommissionDuration(Integer commissionDuration) {
    this.commissionDuration = commissionDuration;
    return this;
  }

  /**
   * Email that this advertiser would like publishers to contact them with.
   * The value returned may be {@code null}.
   */
  public String getContactEmail() {
    return contactEmail;
  }

  /**
   * Email that this advertiser would like publishers to contact them with.
   * The value set may be {@code null}.
   */
  public Advertiser setContactEmail(String contactEmail) {
    this.contactEmail = contactEmail;
    return this;
  }

  /**
   * Phone that this advertiser would like publishers to contact them with.
   * The value returned may be {@code null}.
   */
  public String getContactPhone() {
    return contactPhone;
  }

  /**
   * Phone that this advertiser would like publishers to contact them with.
   * The value set may be {@code null}.
   */
  public Advertiser setContactPhone(String contactPhone) {
    this.contactPhone = contactPhone;
    return this;
  }

  /**
   * The default link id for this advertiser.
   * The value returned may be {@code null}.
   */
  public Long getDefaultLinkId() {
    return defaultLinkId;
  }

  /**
   * The default link id for this advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setDefaultLinkId(Long defaultLinkId) {
    this.defaultLinkId = defaultLinkId;
    return this;
  }

  /**
   * Description of the website the advertiser advertises from.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Description of the website the advertiser advertises from.
   * The value set may be {@code null}.
   */
  public Advertiser setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months. This value should be multiplied by 100 at the time of display.
   * The value returned may be {@code null}.
   */
  public Money getEpcNinetyDayAverage() {
    return epcNinetyDayAverage;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months. This value should be multiplied by 100 at the time of display.
   * The value set may be {@code null}.
   */
  public Advertiser setEpcNinetyDayAverage(Money epcNinetyDayAverage) {
    this.epcNinetyDayAverage = epcNinetyDayAverage;
    return this;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days. This value should be multiplied by 100 at the time of display.
   * The value returned may be {@code null}.
   */
  public Money getEpcSevenDayAverage() {
    return epcSevenDayAverage;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days. This value should be multiplied by 100 at the time of display.
   * The value set may be {@code null}.
   */
  public Advertiser setEpcSevenDayAverage(Money epcSevenDayAverage) {
    this.epcSevenDayAverage = epcSevenDayAverage;
    return this;
  }

  /**
   * The ID of this advertiser.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of this advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * The requested advertiser.
   * The value returned may be {@code null}.
   */
  public Advertiser getItem() {
    return item;
  }

  /**
   * The requested advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setItem(Advertiser item) {
    this.item = item;
    return this;
  }

  /**
   * Date that this advertiser was approved as a Google Affiliate Network advertiser.
   * The value returned may be {@code null}.
   */
  public DateTime getJoinDate() {
    return joinDate;
  }

  /**
   * Date that this advertiser was approved as a Google Affiliate Network advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setJoinDate(DateTime joinDate) {
    this.joinDate = joinDate;
    return this;
  }

  /**
   * The kind for an advertiser.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind for an advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * URL to the logo this advertiser uses on the Google Affiliate Network.
   * The value returned may be {@code null}.
   */
  public String getLogoUrl() {
    return logoUrl;
  }

  /**
   * URL to the logo this advertiser uses on the Google Affiliate Network.
   * The value set may be {@code null}.
   */
  public Advertiser setLogoUrl(String logoUrl) {
    this.logoUrl = logoUrl;
    return this;
  }

  /**
   * List of merchant center ids for this advertiser
   * The value returned may be {@code null}.
   */
  public java.util.List<Long> getMerchantCenterIds() {
    return merchantCenterIds;
  }

  /**
   * List of merchant center ids for this advertiser
   * The value set may be {@code null}.
   */
  public Advertiser setMerchantCenterIds(java.util.List<Long> merchantCenterIds) {
    this.merchantCenterIds = merchantCenterIds;
    return this;
  }

  /**
   * The name of this advertiser.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of this advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * A rank based on commissions paid to publishers over the past 90 days. A number between 1 and 4
   * where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least money
   * paid).
   * The value returned may be {@code null}.
   */
  public String getPayoutRank() {
    return payoutRank;
  }

  /**
   * A rank based on commissions paid to publishers over the past 90 days. A number between 1 and 4
   * where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least money
   * paid).
   * The value set may be {@code null}.
   */
  public Advertiser setPayoutRank(String payoutRank) {
    this.payoutRank = payoutRank;
    return this;
  }

  /**
   * Allows advertisers to submit product listings to Google Product Search.
   * The value returned may be {@code null}.
   */
  public Boolean getProductFeedsEnabled() {
    return productFeedsEnabled;
  }

  /**
   * Allows advertisers to submit product listings to Google Product Search.
   * The value set may be {@code null}.
   */
  public Advertiser setProductFeedsEnabled(Boolean productFeedsEnabled) {
    this.productFeedsEnabled = productFeedsEnabled;
    return this;
  }

  /**
   * List of redirect URLs for this advertiser
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getRedirectDomains() {
    return redirectDomains;
  }

  /**
   * List of redirect URLs for this advertiser
   * The value set may be {@code null}.
   */
  public Advertiser setRedirectDomains(java.util.List<String> redirectDomains) {
    this.redirectDomains = redirectDomains;
    return this;
  }

  /**
   * URL of the website this advertiser advertises from.
   * The value returned may be {@code null}.
   */
  public String getSiteUrl() {
    return siteUrl;
  }

  /**
   * URL of the website this advertiser advertises from.
   * The value set may be {@code null}.
   */
  public Advertiser setSiteUrl(String siteUrl) {
    this.siteUrl = siteUrl;
    return this;
  }

  /**
   * The status of the requesting publisher's relationship this advertiser.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of the requesting publisher's relationship this advertiser.
   * The value set may be {@code null}.
   */
  public Advertiser setStatus(String status) {
    this.status = status;
    return this;
  }

}
