/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.gan.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * A LinkResource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Affiliate Network API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Link extends GenericJson {

  /**
   * The advertiser id for the advertiser who owns this link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long advertiserId;

  /**
   * Authorship
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String authorship;

  /**
   * Availability.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String availability;

  /**
   * Tracking url for clicks.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String clickTrackingUrl;

  /**
   * Date that this link was created.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime createDate;

  /**
   * Description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The destination URL for the link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String destinationUrl;

  /**
   * Duration
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String duration;

  /**
   * Date that this link becomes inactive.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime endDate;

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months on this link. This value should be multiplied by 100 at the time of display.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcNinetyDayAverage;

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days on this link. This value should be multiplied by 100 at the time of display.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcSevenDayAverage;

  /**
   * The ID of this link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * image alt text.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String imageAltText;

  /**
   * Tracking url for impressions.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String impressionTrackingUrl;

  /**
   * Flag for if this link is active.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isActive;

  /**
   * The kind for one entity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The link type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String linkType;

  /**
   * The logical name for this link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Promotion Type
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String promotionType;

  /**
   * Special offers on the link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SpecialOffers specialOffers;

  /**
   * Date that this link becomes active.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime startDate;

  /**
   * The advertiser id for the advertiser who owns this link.
   * The value returned may be {@code null}.
   */
  public Long getAdvertiserId() {
    return advertiserId;
  }

  /**
   * The advertiser id for the advertiser who owns this link.
   * The value set may be {@code null}.
   */
  public Link setAdvertiserId(Long advertiserId) {
    this.advertiserId = advertiserId;
    return this;
  }

  /**
   * Authorship
   * The value returned may be {@code null}.
   */
  public String getAuthorship() {
    return authorship;
  }

  /**
   * Authorship
   * The value set may be {@code null}.
   */
  public Link setAuthorship(String authorship) {
    this.authorship = authorship;
    return this;
  }

  /**
   * Availability.
   * The value returned may be {@code null}.
   */
  public String getAvailability() {
    return availability;
  }

  /**
   * Availability.
   * The value set may be {@code null}.
   */
  public Link setAvailability(String availability) {
    this.availability = availability;
    return this;
  }

  /**
   * Tracking url for clicks.
   * The value returned may be {@code null}.
   */
  public String getClickTrackingUrl() {
    return clickTrackingUrl;
  }

  /**
   * Tracking url for clicks.
   * The value set may be {@code null}.
   */
  public Link setClickTrackingUrl(String clickTrackingUrl) {
    this.clickTrackingUrl = clickTrackingUrl;
    return this;
  }

  /**
   * Date that this link was created.
   * The value returned may be {@code null}.
   */
  public DateTime getCreateDate() {
    return createDate;
  }

  /**
   * Date that this link was created.
   * The value set may be {@code null}.
   */
  public Link setCreateDate(DateTime createDate) {
    this.createDate = createDate;
    return this;
  }

  /**
   * Description.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Description.
   * The value set may be {@code null}.
   */
  public Link setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The destination URL for the link.
   * The value returned may be {@code null}.
   */
  public String getDestinationUrl() {
    return destinationUrl;
  }

  /**
   * The destination URL for the link.
   * The value set may be {@code null}.
   */
  public Link setDestinationUrl(String destinationUrl) {
    this.destinationUrl = destinationUrl;
    return this;
  }

  /**
   * Duration
   * The value returned may be {@code null}.
   */
  public String getDuration() {
    return duration;
  }

  /**
   * Duration
   * The value set may be {@code null}.
   */
  public Link setDuration(String duration) {
    this.duration = duration;
    return this;
  }

  /**
   * Date that this link becomes inactive.
   * The value returned may be {@code null}.
   */
  public DateTime getEndDate() {
    return endDate;
  }

  /**
   * Date that this link becomes inactive.
   * The value set may be {@code null}.
   */
  public Link setEndDate(DateTime endDate) {
    this.endDate = endDate;
    return this;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months on this link. This value should be multiplied by 100 at the time of display.
   * The value returned may be {@code null}.
   */
  public Money getEpcNinetyDayAverage() {
    return epcNinetyDayAverage;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past three
   * months on this link. This value should be multiplied by 100 at the time of display.
   * The value set may be {@code null}.
   */
  public Link setEpcNinetyDayAverage(Money epcNinetyDayAverage) {
    this.epcNinetyDayAverage = epcNinetyDayAverage;
    return this;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days on this link. This value should be multiplied by 100 at the time of display.
   * The value returned may be {@code null}.
   */
  public Money getEpcSevenDayAverage() {
    return epcSevenDayAverage;
  }

  /**
   * The sum of fees paid to publishers divided by the total number of clicks over the past seven
   * days on this link. This value should be multiplied by 100 at the time of display.
   * The value set may be {@code null}.
   */
  public Link setEpcSevenDayAverage(Money epcSevenDayAverage) {
    this.epcSevenDayAverage = epcSevenDayAverage;
    return this;
  }

  /**
   * The ID of this link.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of this link.
   * The value set may be {@code null}.
   */
  public Link setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * image alt text.
   * The value returned may be {@code null}.
   */
  public String getImageAltText() {
    return imageAltText;
  }

  /**
   * image alt text.
   * The value set may be {@code null}.
   */
  public Link setImageAltText(String imageAltText) {
    this.imageAltText = imageAltText;
    return this;
  }

  /**
   * Tracking url for impressions.
   * The value returned may be {@code null}.
   */
  public String getImpressionTrackingUrl() {
    return impressionTrackingUrl;
  }

  /**
   * Tracking url for impressions.
   * The value set may be {@code null}.
   */
  public Link setImpressionTrackingUrl(String impressionTrackingUrl) {
    this.impressionTrackingUrl = impressionTrackingUrl;
    return this;
  }

  /**
   * Flag for if this link is active.
   * The value returned may be {@code null}.
   */
  public Boolean getIsActive() {
    return isActive;
  }

  /**
   * Flag for if this link is active.
   * The value set may be {@code null}.
   */
  public Link setIsActive(Boolean isActive) {
    this.isActive = isActive;
    return this;
  }

  /**
   * The kind for one entity.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind for one entity.
   * The value set may be {@code null}.
   */
  public Link setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The link type.
   * The value returned may be {@code null}.
   */
  public String getLinkType() {
    return linkType;
  }

  /**
   * The link type.
   * The value set may be {@code null}.
   */
  public Link setLinkType(String linkType) {
    this.linkType = linkType;
    return this;
  }

  /**
   * The logical name for this link.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The logical name for this link.
   * The value set may be {@code null}.
   */
  public Link setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Promotion Type
   * The value returned may be {@code null}.
   */
  public String getPromotionType() {
    return promotionType;
  }

  /**
   * Promotion Type
   * The value set may be {@code null}.
   */
  public Link setPromotionType(String promotionType) {
    this.promotionType = promotionType;
    return this;
  }

  /**
   * Special offers on the link.
   * The value returned may be {@code null}.
   */
  public SpecialOffers getSpecialOffers() {
    return specialOffers;
  }

  /**
   * Special offers on the link.
   * The value set may be {@code null}.
   */
  public Link setSpecialOffers(SpecialOffers specialOffers) {
    this.specialOffers = specialOffers;
    return this;
  }

  /**
   * Date that this link becomes active.
   * The value returned may be {@code null}.
   */
  public DateTime getStartDate() {
    return startDate;
  }

  /**
   * Date that this link becomes active.
   * The value set may be {@code null}.
   */
  public Link setStartDate(DateTime startDate) {
    this.startDate = startDate;
    return this;
  }

  /**
   * Special offers on the link.
   */
  public static final class SpecialOffers extends GenericJson {

    /**
     * Whether there is a free gift
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean freeGift;

    /**
     * Whether there is free shipping
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean freeShipping;

    /**
     * Minimum purchase amount for free shipping promotion
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Money freeShippingMin;

    /**
     * Percent off on the purchase
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double percentOff;

    /**
     * Minimum purchase amount for percent off promotion
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Money percentOffMin;

    /**
     * Price cut on the purchase
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Money priceCut;

    /**
     * Minimum purchase amount for price cut promotion
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Money priceCutMin;

    /**
     * List of promotion code associated with the link
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> promotionCodes;

    /**
     * Whether there is a free gift
     * The value returned may be {@code null}.
     */
    public Boolean getFreeGift() {
      return freeGift;
    }

    /**
     * Whether there is a free gift
     * The value set may be {@code null}.
     */
    public SpecialOffers setFreeGift(Boolean freeGift) {
      this.freeGift = freeGift;
      return this;
    }

    /**
     * Whether there is free shipping
     * The value returned may be {@code null}.
     */
    public Boolean getFreeShipping() {
      return freeShipping;
    }

    /**
     * Whether there is free shipping
     * The value set may be {@code null}.
     */
    public SpecialOffers setFreeShipping(Boolean freeShipping) {
      this.freeShipping = freeShipping;
      return this;
    }

    /**
     * Minimum purchase amount for free shipping promotion
     * The value returned may be {@code null}.
     */
    public Money getFreeShippingMin() {
      return freeShippingMin;
    }

    /**
     * Minimum purchase amount for free shipping promotion
     * The value set may be {@code null}.
     */
    public SpecialOffers setFreeShippingMin(Money freeShippingMin) {
      this.freeShippingMin = freeShippingMin;
      return this;
    }

    /**
     * Percent off on the purchase
     * The value returned may be {@code null}.
     */
    public Double getPercentOff() {
      return percentOff;
    }

    /**
     * Percent off on the purchase
     * The value set may be {@code null}.
     */
    public SpecialOffers setPercentOff(Double percentOff) {
      this.percentOff = percentOff;
      return this;
    }

    /**
     * Minimum purchase amount for percent off promotion
     * The value returned may be {@code null}.
     */
    public Money getPercentOffMin() {
      return percentOffMin;
    }

    /**
     * Minimum purchase amount for percent off promotion
     * The value set may be {@code null}.
     */
    public SpecialOffers setPercentOffMin(Money percentOffMin) {
      this.percentOffMin = percentOffMin;
      return this;
    }

    /**
     * Price cut on the purchase
     * The value returned may be {@code null}.
     */
    public Money getPriceCut() {
      return priceCut;
    }

    /**
     * Price cut on the purchase
     * The value set may be {@code null}.
     */
    public SpecialOffers setPriceCut(Money priceCut) {
      this.priceCut = priceCut;
      return this;
    }

    /**
     * Minimum purchase amount for price cut promotion
     * The value returned may be {@code null}.
     */
    public Money getPriceCutMin() {
      return priceCutMin;
    }

    /**
     * Minimum purchase amount for price cut promotion
     * The value set may be {@code null}.
     */
    public SpecialOffers setPriceCutMin(Money priceCutMin) {
      this.priceCutMin = priceCutMin;
      return this;
    }

    /**
     * List of promotion code associated with the link
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getPromotionCodes() {
      return promotionCodes;
    }

    /**
     * List of promotion code associated with the link
     * The value set may be {@code null}.
     */
    public SpecialOffers setPromotionCodes(java.util.List<String> promotionCodes) {
      this.promotionCodes = promotionCodes;
      return this;
    }

  }

}
