/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.gan.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * A PublisherResource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Affiliate Network API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Publisher extends GenericJson {

  /**
   * Classification that this publisher belongs to. See this link for all publisher classifications:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107625=cb=cb=-k5f
   * ihzthfaik=4
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String classification;

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * three months. Values are multiplied by 100 for display purposes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcNinetyDayAverage;

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * seven days. Values are multiplied by 100 for display purposes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Money epcSevenDayAverage;

  /**
   * The ID of this publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * The requested publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Publisher item;

  /**
   * Date that this publisher was approved as a Google Affiliate Network publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime joinDate;

  /**
   * The kind for a publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The name of this publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * A rank based on commissions paid to this publisher over the past 90 days. A number between 1
   * and 4 where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least
   * money paid).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String payoutRank;

  /**
   * Websites that this publisher uses to advertise.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> sites;

  /**
   * The status of the requesting advertiser's relationship with this publisher.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Classification that this publisher belongs to. See this link for all publisher classifications:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107625=cb=cb=-k5f
   * ihzthfaik=4
   * The value returned may be {@code null}.
   */
  public String getClassification() {
    return classification;
  }

  /**
   * Classification that this publisher belongs to. See this link for all publisher classifications:
   * http://www.google.com/support/affiliatenetwork/advertiser/bin/answer.py?hl=en=107625=cb=cb=-k5f
   * ihzthfaik=4
   * The value set may be {@code null}.
   */
  public Publisher setClassification(String classification) {
    this.classification = classification;
    return this;
  }

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * three months. Values are multiplied by 100 for display purposes.
   * The value returned may be {@code null}.
   */
  public Money getEpcNinetyDayAverage() {
    return epcNinetyDayAverage;
  }

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * three months. Values are multiplied by 100 for display purposes.
   * The value set may be {@code null}.
   */
  public Publisher setEpcNinetyDayAverage(Money epcNinetyDayAverage) {
    this.epcNinetyDayAverage = epcNinetyDayAverage;
    return this;
  }

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * seven days. Values are multiplied by 100 for display purposes.
   * The value returned may be {@code null}.
   */
  public Money getEpcSevenDayAverage() {
    return epcSevenDayAverage;
  }

  /**
   * The sum of fees paid to this publisher divided by the total number of clicks over the past
   * seven days. Values are multiplied by 100 for display purposes.
   * The value set may be {@code null}.
   */
  public Publisher setEpcSevenDayAverage(Money epcSevenDayAverage) {
    this.epcSevenDayAverage = epcSevenDayAverage;
    return this;
  }

  /**
   * The ID of this publisher.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of this publisher.
   * The value set may be {@code null}.
   */
  public Publisher setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * The requested publisher.
   * The value returned may be {@code null}.
   */
  public Publisher getItem() {
    return item;
  }

  /**
   * The requested publisher.
   * The value set may be {@code null}.
   */
  public Publisher setItem(Publisher item) {
    this.item = item;
    return this;
  }

  /**
   * Date that this publisher was approved as a Google Affiliate Network publisher.
   * The value returned may be {@code null}.
   */
  public DateTime getJoinDate() {
    return joinDate;
  }

  /**
   * Date that this publisher was approved as a Google Affiliate Network publisher.
   * The value set may be {@code null}.
   */
  public Publisher setJoinDate(DateTime joinDate) {
    this.joinDate = joinDate;
    return this;
  }

  /**
   * The kind for a publisher.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind for a publisher.
   * The value set may be {@code null}.
   */
  public Publisher setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The name of this publisher.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of this publisher.
   * The value set may be {@code null}.
   */
  public Publisher setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * A rank based on commissions paid to this publisher over the past 90 days. A number between 1
   * and 4 where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least
   * money paid).
   * The value returned may be {@code null}.
   */
  public String getPayoutRank() {
    return payoutRank;
  }

  /**
   * A rank based on commissions paid to this publisher over the past 90 days. A number between 1
   * and 4 where 4 means the top quartile (most money paid) and 1 means the bottom quartile (least
   * money paid).
   * The value set may be {@code null}.
   */
  public Publisher setPayoutRank(String payoutRank) {
    this.payoutRank = payoutRank;
    return this;
  }

  /**
   * Websites that this publisher uses to advertise.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getSites() {
    return sites;
  }

  /**
   * Websites that this publisher uses to advertise.
   * The value set may be {@code null}.
   */
  public Publisher setSites(java.util.List<String> sites) {
    this.sites = sites;
    return this;
  }

  /**
   * The status of the requesting advertiser's relationship with this publisher.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of the requesting advertiser's relationship with this publisher.
   * The value set may be {@code null}.
   */
  public Publisher setStatus(String status) {
    this.status = status;
    return this;
  }

}
